@@ -31,7 +31,7 @@ async def create_room(room: _RoomType):
 
 
 async def delete_room(room_id: str):
-    await redis_client.execute_command('JSON.DELETE', get_room_key(room_id), Path.root_path())
+    await redis_client.execute_command('JSON.DEL', get_room_key(room_id), Path.root_path())
 
 
 async def get_room(room_id: str, model: type[_RoomType]) -> _RoomType:
