@@ -1,6 +1,6 @@
 from moontour_common.models.coordinates import Coordinates
 from moontour_common.models.guess import Guess
-from moontour_common.models.phase import PhaseStatus, Phase, HealthPhase
+from moontour_common.models.phase import PhaseStatus, Phase
 from moontour_common.models.rooms.duel_room import DuelPlayer, DuelRoom
 from moontour_common.models.rooms.room import RoomStatus, BaseRoom
 from moontour_common.models.rooms.streak_room import StreakRoom
