@@ -18,7 +18,3 @@ class Phase(BaseModel):
     create_time: datetime = Field(default_factory=datetime.now)
     start_time: datetime | None = None
     end_time: datetime | None
-
-
-class HealthPhase(Phase):
-    damage_multiplier: float = 1
