@@ -1,6 +1,5 @@
-from pydantic import validator
-
-from moontour_common.models.rooms.health_room import HealthRoom, START_HEALTH
+from moontour_common.models import Guess
+from moontour_common.models.rooms.health_room import HealthRoom, START_HEALTH, HealthPhase
 from moontour_common.models.rooms.room import RoomMode
 from moontour_common.models.user import User
 
@@ -9,6 +8,10 @@ class DuelPlayer(User):
     health: int = START_HEALTH
 
 
+class DuelPhase(HealthPhase):
+    guesses: dict[str, Guess] = {}  # User ID to guess
+
+
 class DuelRoom(HealthRoom):
     @staticmethod
     def get_mode() -> RoomMode:
@@ -16,3 +19,4 @@ class DuelRoom(HealthRoom):
 
     player_count: int = 2
     players: list[DuelPlayer] = []
+    phases: list[DuelPhase] = []
